/**
  ******************************************************************************
  * @file    stm32f7_som_nor_flash.h
  * @author  Yuri Tikhonov <yur@emcraft.com>
  * @version V1.0.0
  * @date    29-December-2017
  * @brief   This file contains definitions for STM32F7-SOM NOR Flash
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2017 EmCraft Systems</center></h2>
  * <h2><center>&copy; COPYRIGHT(c) 2016 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __STM32F7_SOM_NOR_FLASH_H
#define __STM32F7_SOM_NOR_FLASH_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "stm32f7xx_hal.h"

/* Constants -----------------------------------------------------------------*/
#define NOR_DEVICE_ADDR		((uint32_t)0x60000000)

#define NOR_STATUS_OK		((uint8_t)0x00)
#define NOR_STATUS_ERROR	((uint8_t)0x01)

/* NOR operations Timeout definitions */
#define BLOCKERASE_TIMEOUT	((uint32_t)0x00A00000)	/* NOR block erase timeout */
#define CHIPERASE_TIMEOUT	((uint32_t)0x30000000)	/* NOR chip erase timeout  */
#define PROGRAM_TIMEOUT		((uint32_t)0x00004400)	/* NOR program timeout     */

/* SDRAM API -----------------------------------------------------------------*/
uint8_t BSP_NOR_Init(void);
uint8_t BSP_NOR_DeInit(void);
uint8_t BSP_NOR_ReadData(uint32_t uwStartAddress, uint16_t * pData,
			 uint32_t uwDataSize);
uint8_t BSP_NOR_WriteData(uint32_t uwStartAddress, uint16_t * pData,
			  uint32_t uwDataSize);
uint8_t BSP_NOR_ProgramData(uint32_t uwStartAddress, uint16_t * pData,
			    uint32_t uwDataSize);
uint8_t BSP_NOR_Erase_Block(uint32_t BlockAddress);
uint8_t BSP_NOR_Erase_Chip(void);
uint8_t BSP_NOR_Read_ID(NOR_IDTypeDef * pNOR_ID);
void BSP_NOR_ReturnToReadMode(void);

void BSP_NOR_MspInit(NOR_HandleTypeDef * hnor, void *Params);
void BSP_NOR_MspDeInit(NOR_HandleTypeDef * hnor, void *Params);

#ifdef __cplusplus
}
#endif
#endif	/* __STM32F7_SOM_NOR_FLASH_H */
