/*----------------------------------------------------------------------------
 * Name:    Test_NOR.c
 * Purpose: NOR Flash test routines for STM32F7-SOM
 *----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2017 - EmCraft Systems. All rights reserved.
 *----------------------------------------------------------------------------*/

#include "cmsis_os.h"		/* ARM::CMSIS:RTOS:Keil RTX */
#include "stm32f7_som_nor_flash.h"

#include <stdio.h>
#include <string.h>

#define NOR_TEST_ADDRESS	0x100
#define NOR_TEST_LEN		16

int Test_NOR(void)
{
	NOR_IDTypeDef id;
	uint16_t buf[NOR_TEST_LEN];
	int i, rv, err = 1;

	/* Init NOR, and get ID */
	rv = BSP_NOR_Init();
	if (rv) {
		printf("NOR: init error %d\n", rv);
		goto out;
	}

	memset(&id, 0, sizeof(id));
	BSP_NOR_Read_ID(&id);
	if (id.Manufacturer_Code != 0x0001 || id.Device_Code1 != 0x227E) {
		printf("NOR: bad manufacture/device id %04x/%04x.%04x.%04x\n",
		       id.Manufacturer_Code, id.Device_Code1, id.Device_Code2,
		       id.Device_Code3);
		goto out;
	}

	BSP_NOR_ReturnToReadMode();
	rv = BSP_NOR_Erase_Block(0x0);
	if (rv) {
		printf("NOR: erase error %d\n", rv);
		goto out;
	}

	rv = BSP_NOR_ReadData(NOR_TEST_ADDRESS, buf, NOR_TEST_LEN);
	if (rv) {
		printf("NOR: read (after erase) error %d\n", rv);
		goto out;
	}
	for (i = 0; i < NOR_TEST_LEN; i++) {
		if (buf[i] != 0xFFFF) {
			printf("NOR: read bad val (after erase) %04x @ %08x\n",
			       buf[i], NOR_TEST_ADDRESS + i);
			goto out;
		}
	}

	for (i = 0; i < NOR_TEST_LEN; i++)
		buf[i] = i | ((i + 1) << 8);

	rv = BSP_NOR_WriteData(NOR_TEST_ADDRESS, buf, NOR_TEST_LEN);
	if (rv) {
		printf("NOR: write error %d\n", rv);
		goto out;
	}

	rv = BSP_NOR_ReadData(NOR_TEST_ADDRESS, buf, NOR_TEST_LEN);
	if (rv) {
		printf("NOR: read (after erase) error %d\n", rv);
		goto out;
	}
	for (i = 0; i < NOR_TEST_LEN; i++) {
		if (buf[i] == (i | ((i + 1) << 8)))
			continue;
		printf("NOR: read bad value %04x (expect %04x) @ %08x\n",
		       buf[i], i | ((i + 1) << 8), NOR_TEST_ADDRESS + i);
		goto out;
	}
	err = 0;
 out:
	printf("NOR: test %s\n", err ? "FAILED" : "PASSED");
	return err;
}
