/*----------------------------------------------------------------------------
 * Name:    Test_SDRAM.c
 * Purpose: SDRAM test routines for STM32F7-SOM
 *----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2017 - EmCraft Systems. All rights reserved.
 *----------------------------------------------------------------------------*/

#include "cmsis_os.h"		/* ARM::CMSIS:RTOS:Keil RTX */
#include "stm32f7_som_sdram.h"

#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#define SDRAM_TEST_ADDRESS	(SDRAM_BASE_ADDRESS + 0x10000)
#define SDRAM_TEST_LEN			16

int Test_SDRAM(void)
{
	uint32_t buf[SDRAM_TEST_LEN];
	uint8_t *p = NULL;
	int i, rv, err = 1;

	/*
	 * No need to call BSP_SDRAM_Init() here. This function is called from
	 * SystemInit() early, so that we'd be able to allocate stack and/or
	 * heap in SDRAM.
	 */

	/*
	 * Basic SDRAM I/O test
	 */
	rv = BSP_SDRAM_ReadData(SDRAM_TEST_ADDRESS, buf, SDRAM_TEST_LEN);
	if (rv) {
		printf("SDRAM: read (after init) error %d\n", rv);
		goto out;
	}

	for (i = 0; i < SDRAM_TEST_LEN; i++)
		buf[i] = i | ((i + 1) << 8);

	rv = BSP_SDRAM_WriteData(SDRAM_TEST_ADDRESS, buf, SDRAM_TEST_LEN);
	if (rv) {
		printf("SDRAM: write error %d\n", rv);
		goto out;
	}

	rv = BSP_SDRAM_ReadData(SDRAM_TEST_ADDRESS, buf, SDRAM_TEST_LEN);
	if (rv) {
		printf("SDRAM: read (after write) error %d\n", rv);
		goto out;
	}
	for (i = 0; i < SDRAM_TEST_LEN; i++) {
		if (buf[i] == (i | ((i + 1) << 8)))
			continue;
		printf
		    ("SDRAM: read bad value 0x%04x (expect 0x%04x) @ 0x%08x\n",
		     buf[i], i | ((i + 1) << 8), SDRAM_TEST_ADDRESS + i);
		goto out;
	}

	/*
	 * Check if malloc() is working as expected
	 */
	p = malloc(SDRAM_TEST_LEN);
	if (!p) {
		printf("HEAP: failed malloc(%d)\n", SDRAM_TEST_LEN);
		goto out;
	}
	printf("HEAP: located in %s (0x%p)\n",
	       (uint32_t) p < SDRAM_BASE_ADDRESS ? "SRAM" : "SDRAM", p);

	for (i = 0; i < SDRAM_TEST_LEN; i++)
		p[i] = i;
	for (i = 0; i < SDRAM_TEST_LEN; i++) {
		if (p[i] == i)
			continue;
		printf("HEAP: read bad value 0x%02x (expect 0x%02x) @ 0x%p\n",
		       p[i], i, &p[i]);
		goto out;
	}

	err = 0;
 out:
	printf("SDRAM: test %s\n", err ? "FAILED" : "PASSED");
	if (p)
		free(p);

	return err;
}
