/*----------------------------------------------------------------------------
 * Name:    Thread_NET.c
 * Purpose: NET test routines for STM32F7-SOM
 *----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2017 - EmCraft Systems. All rights reserved.
 *----------------------------------------------------------------------------*/

#include "cmsis_os.h"		/* ARM::CMSIS:RTOS:Keil RTX */
#include "rl_net.h"

#include <stdio.h>
#include <string.h>

/*
 * The Host address to ping
 */
const NET_ADDR host = { NET_ADDR_IP4, 0, 192, 168, 1, 65 };

void Thread_NET(void const *argument);
osThreadId tid_Thread_NET;
osThreadDef(Thread_NET, osPriorityNormal, 1, 0);

int Init_Thread_NET(void)
{
	tid_Thread_NET = osThreadCreate(osThread(Thread_NET), NULL);
	printf("NET TASK_ID = 0x%X\r\n", (int)tid_Thread_NET);
	return tid_Thread_NET ? 0 : -1;
}

static void ping_callback(netPing_Event event)
{
	switch (event) {
	case netPing_EventSuccess:
		printf("+++ Remote host responded to ping.\n");
		break;
	case netPing_EventTimeout:
		printf("--- Ping timeout, no response.\n");
		break;
	}
}

int ping_host(const NET_ADDR * addr)
{
	return netPing_Echo(addr, ping_callback);
}

/* CMSIS-RTOS Thread - NET command thread */
void Thread_NET(const void *args)
{
	netInitialize();

	while (1) {
		ping_host(&host);
		osDelay(5000);	/* Wait 5sec */
	}
}
