/*----------------------------------------------------------------------------
 * Name:    Thread_UART.c
 * Purpose: UART test routines for STM32F7-SOM
 *----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2017 - EmCraft Systems. All rights reserved.
 *----------------------------------------------------------------------------*/

#include "Driver_USART.h"
#include "cmsis_os.h"		/* ARM::CMSIS:RTOS:Keil RTX */
#include <stdio.h>
#include <string.h>

void Thread_UART(void const *argument);
osThreadId tid_Thread_UART;
osThreadDef(Thread_UART, osPriorityNormal, 1, 0);

/* USART Driver */
extern ARM_DRIVER_USART Driver_USART1;

int Init_Thread_UART(void)
{
	tid_Thread_UART = osThreadCreate(osThread(Thread_UART), NULL);
	printf("UART TASK_ID = 0x%X\r\n", (int)tid_Thread_UART);

	return tid_Thread_UART ? 0 : -1;
}

/* CMSIS-RTOS Thread - UART command thread */
void Thread_UART(const void *args)
{
	static ARM_DRIVER_USART *USARTdrv = &Driver_USART1;

	/*Initialize the USART driver */
	USARTdrv->Initialize(NULL);

	/*Power up the USART peripheral */
	USARTdrv->PowerControl(ARM_POWER_FULL);
	/*Configure the USART to 4800 Bits/sec */
	USARTdrv->Control(ARM_USART_MODE_ASYNCHRONOUS |
			  ARM_USART_DATA_BITS_8 |
			  ARM_USART_PARITY_NONE |
			  ARM_USART_STOP_BITS_1 |
			  ARM_USART_FLOW_CONTROL_NONE, 115200);

	/* Enable Transmitter line only */
	USARTdrv->Control(ARM_USART_CONTROL_TX, 1);

	while (1) {
		/* Wait for signal */
		osSignalWait(1U, osWaitForever);
		USARTdrv->Send(".", 1);
	}
}
